@@ -2,7 +2,7 @@
                           codegenerator.h  -  description
                              -------------------
     begin                : Die Jul 9 2002
-    copyright            : (C) 2002-2015 by Andre Simon
+    copyright            : (C) 2002-2018 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -105,8 +105,35 @@ public:
     Codegenerator is a singleton class.<br>
     Use getInstance for a singleton class instance. Then call the init* methods
     and loadLanguage to initialize the parser. Init methods have to be called first.
-    Call generate* methods to get results.
-
+    Call generate* methods to get results.<br><br>
+    
+    Parser workflow (neglecting embedded syntax and other details):
+    
+    This flow chart shows the method calls, starting in processRootState:
+    
+    -> lineIndex=0
+    -> processRootState()
+       -> state = getCurrentState()
+          -> c = getInputChar()
+             -> increase lineIndex
+             -> if new line: matchRegex()
+                -> cycle through all regexes of Syntaxreader:
+                   KEYWORD, COMMENT, IDENTIFIER, NUMBER, STRING, INTERPOLATION, 
+                   PREPROCESSOR, OPERATOR, NESTEDSECTIONS
+                -> save position and length of a match for the current line
+          -> is there a match at line[lineIndex]?
+             -> YES: - token = match substring of line
+                     - lineIndex = lineIndex + length of token
+                     - call OnStateChange chunk if available
+                     - state = state of the associated regex or OnStateChange return value
+             -> NO:  - token=c
+                     - state = STANDARD
+        -> state is used to determine the next process* method to call. There
+           are process methods for each state (ie processKeywordState, processNumberState).
+           These methods open and close the delimiter tags in the output format, and most
+           importantly decide when the state ends. They also limit the allowed state changes,
+           like INTERPOLATION in STRING.
+          
 * @author Andre Simon
 */
 
@@ -439,6 +466,10 @@ public:
      */
     virtual void setESCTrueColor ( bool )  {};
 
+     /** set background padding width (<=0 to disable)
+     */
+    virtual void setESCCanvasPadding ( unsigned int )  {};
+
 protected:
 
     static const unsigned int NUMBER_BUILTIN_STATES;  ///< number of token states (without keyword group IDs)
@@ -515,7 +546,7 @@ protected:
 
     /** Test if whitespace should always be separated from enclosing tokens */
     bool excludeWs;
-
+	
     /** Test if header and footer should be omitted */
     bool fragmentOutput;
 
@@ -571,9 +602,12 @@ protected:
     */
     unsigned int getStyleID ( State s, unsigned int kwClassID = 0 );
 
-    /** \return line index */
+    /** \return current line index */
     unsigned int getLineIndex();
 
+    /** \return last line index */
+    unsigned int getLastLineLength();
+    
     /** print all remaining white space*/
     void flushWs();
 
@@ -613,6 +647,11 @@ protected:
      *  If the line is just the continuation of a wrapped line,
      *  and numberWrappedLines is false, this is set true. */
     bool numberCurrentLine;
+    
+    /** method to fix output type in Lua state for XHTML and Truecolor 
+        @param output type */
+    void setOutputType(OutputType t) { outputType = t; }
+    
 private:
 
     CodeGenerator ( const CodeGenerator& ) {}
@@ -686,6 +725,9 @@ private:
     /// contains current position in line
     unsigned int lineIndex;
 
+    /// contains length of last line
+    unsigned int lastLineLength;
+
     /// line index where syntax change takes place
     unsigned int syntaxChangeIndex;
 
